@@ -32,6 +32,7 @@
 #include "rsvg.h"
 #include "rsvg-private.h"
 #include "rsvg-tools-main.h"
+#include "rsvg-compat.h"
 
 static gboolean
 read_contents (const gchar *file_name, guint8 **contents, gsize *length)
@@ -127,7 +128,7 @@ rsvg_tools_main (int *argc, char ***argv)
         exit (EXIT_FAILURE);
     }
 
-    g_type_init ();
+    RSVG_G_TYPE_INIT;
 
     for (j = 0; j < n_args; j++) {
         if (!read_contents (args[j], &contents, &length))
